@@ -57,4 +57,13 @@ standard_scale_10k = [0,100,300,1000,3000,10000]
 
 dictionary_stand_10k = norm_dict(standard_scale_10k)
 dictionary_stand_1p_10k = log1p_dict(standard_scale_1p_2p_10k)
-dictionary_stand_2p_10k = log2p_dict(standard_scale_1p_2p_10k)
\ No newline at end of file
+dictionary_stand_2p_10k = log2p_dict(standard_scale_1p_2p_10k)
+
+
+"""
+Scale for dichotomous output from 0 to 1 
+"""
+
+dichotomous_scale_0_1 = [0.00, 0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70, 0.80, 0.90, 1.00]
+dictionary_dichotomous_stand = norm_dict(dichotomous_scale_0_1)
+
