@@ -20,6 +20,16 @@ def vid2date(month_id):
     month=str(ViewsMonth(month_id).month)
     return year+'/'+month
 
+def vid2date_version2(month_id):
+    """
+    Writes a label in standard year_month format from month_id
+    :param month_id:
+    :return: year_month date
+    """
+    year=str(ViewsMonth(month_id).year)
+    month=str(ViewsMonth(month_id).month)
+    return year+'_'+month
+
 def date2id(date_string):
     """
     Writes month id from date, iso format
@@ -120,3 +130,28 @@ def make_a_folder(folderpath):
     else:
         print('Directory', folderpath, 'already exists')
 
+def make_folders_complete_set(main_folderpath):
+    #main folder
+    make_a_folder(main_folderpath)
+    #Dichotomous subfolders
+    make_a_folder(main_folderpath+'/Dichotomous')
+    make_a_folder(main_folderpath+'/Dichotomous'+'/Ensemble')
+    make_a_folder(main_folderpath+'/Dichotomous'+'/Ensemble'+'/ForecastMaps')
+    make_a_folder(main_folderpath+'/Dichotomous'+'/Ensemble'+'/ChangeMaps')
+    make_a_folder(main_folderpath+'/Dichotomous'+'/Ensemble'+'/LineGraphs')
+    #Continous subfolders
+    make_a_folder(main_folderpath+'/Continuous')
+    #Continous ensemble subfolders
+    make_a_folder(main_folderpath+'/Continuous'+'/Ensemble')
+    make_a_folder(main_folderpath+'/Continuous'+'/Ensemble'+'/ForecastMaps')
+    make_a_folder(main_folderpath+'/Continuous'+'/Ensemble'+'/ChangeMaps')
+    make_a_folder(main_folderpath+'/Continuous'+'/Ensemble'+'/LineGraphs')
+    make_a_folder(main_folderpath+'/Continuous'+'/Ensemble'+'/PieCharts')
+    make_a_folder(main_folderpath+'/Continuous'+'/Ensemble'+'/BarCharts')
+    #Continuous interpretation subfolders
+    make_a_folder(main_folderpath+'/Continuous'+'/Interpretation')
+    make_a_folder(main_folderpath+'/Continuous'+'/Interpretation'+'/Plots')
+    #Features subfolder
+    make_a_folder(main_folderpath+'/Features')
+
+
